@@ -1,9 +1,17 @@
 from time import sleep
+from unittest import SkipTest
 from parameterized import parameterized
+from tenacity import retry, stop_after_attempt, retry_if_exception
 from integration.conftest import clean_bucket
 from integration.helpers.base_test import S3_BUCKET_PREFIX, BaseTest
 from integration.helpers.resource import generate_suffix
 
+retry_once = retry(
+    stop=stop_after_attempt(2),
+    # unittest raises SkipTest for skipping tests
+    retry=retry_if_exception(lambda e: not isinstance(e, SkipTest)),
+)
+
 
 class TestConnectors(BaseTest):
     def tearDown(self):
@@ -41,6 +49,7 @@ class TestConnectors(BaseTest):
             ("combination/connector_table_to_function_read",),
         ]
     )
+    @retry_once
     def test_connector_by_invoking_a_function(self, template_file_path):
         self.skip_using_service_detector(template_file_path)
         self.create_and_verify_stack(template_file_path)
@@ -72,6 +81,7 @@ class TestConnectors(BaseTest):
             ("combination/connector_sfn_to_eb_custom_write",),
         ]
     )
+    @retry_once
     def test_connector_by_sync_execute_an_state_machine(self, template_file_path):
         self.skip_using_service_detector(template_file_path)
         self.create_and_verify_stack(template_file_path)
@@ -91,6 +101,7 @@ class TestConnectors(BaseTest):
             ("combination/connector_sfn_to_sfn_sync",),
         ]
     )
+    @retry_once
     def test_connector_by_async_execute_an_state_machine(self, template_file_path):
         self.skip_using_service_detector(template_file_path)
         self.create_and_verify_stack(template_file_path)
@@ -123,6 +134,7 @@ class TestConnectors(BaseTest):
             ("combination/connector_bucket_to_function_write",),
         ]
     )
+    @retry_once
     def test_connector_by_execute_a_s3_bucket(self, template_file_path):
         self.skip_using_service_detector(template_file_path)
         bucket_name = S3_BUCKET_PREFIX + "connector" + generate_suffix()
