@@ -1,8 +1,19 @@
+from unittest.case import skipIf
+import pytest
+
 from integration.helpers.base_test import BaseTest
+from integration.helpers.resource import current_region_not_included
+
+from integration.config.service_names import SELF_MANAGED_KAFKA
 from parameterized import parameterized
 
 
+@skipIf(
+    current_region_not_included([SELF_MANAGED_KAFKA]),
+    "SelfManagedKafka testing is not performed in this testing region",
+)
 class TestFunctionWithSelfManagedKafka(BaseTest):
+    @pytest.mark.flaky(reruns=5)
     @parameterized.expand(
         [
             "combination/function_with_self_managed_kafka",
