@@ -27,6 +27,7 @@ class LambdaFunction(Resource):
         "CodeSigningConfigArn": PropertyType(False, is_str()),
         "ImageConfig": PropertyType(False, is_type(dict)),
         "Architectures": PropertyType(False, list_of(one_of(is_str(), is_type(dict)))),
+        "SnapStart": PropertyType(False, is_type(dict)),
         "EphemeralStorage": PropertyType(False, is_type(dict)),
     }
 
@@ -81,6 +82,8 @@ class LambdaEventSourceMapping(Resource):
         "FunctionResponseTypes": PropertyType(False, is_type(list)),
         "SelfManagedEventSource": PropertyType(False, is_type(dict)),
         "FilterCriteria": PropertyType(False, is_type(dict)),
+        "AmazonManagedKafkaEventSourceConfig": PropertyType(False, is_type(dict)),
+        "SelfManagedKafkaEventSourceConfig": PropertyType(False, is_type(dict)),
     }
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id)}
